summaryrefslogtreecommitdiff
path: root/xmlsecurity/source/helper/documentsignaturehelper.cxx
diff options
context:
space:
mode:
authorMiklos Vajna <vmiklos@collabora.co.uk>2016-01-05 10:38:39 +0100
committerMiklos Vajna <vmiklos@collabora.co.uk>2016-01-05 14:55:40 +0100
commitee2b08ed8a1a6a588b01d6c5e845fc92c651af5d (patch)
tree8d587a373cc136d8d6d5ef2548fcbd8d243fb903 /xmlsecurity/source/helper/documentsignaturehelper.cxx
parent9adca57fda39c0e5cfdd7b1d9232ed4bf7f04845 (diff)
xmlsecurity: convert TYPE_...__REFERENCE constants to scoped enum
Change-Id: Ic2248b3bc6460e65bdf4eb30af4f8893a7f0e68d
Diffstat (limited to 'xmlsecurity/source/helper/documentsignaturehelper.cxx')
-rw-r--r--xmlsecurity/source/helper/documentsignaturehelper.cxx4
1 files changed, 2 insertions, 2 deletions
diff --git a/xmlsecurity/source/helper/documentsignaturehelper.cxx b/xmlsecurity/source/helper/documentsignaturehelper.cxx
index 3b44a40e6ff1..08a4f0b48e8b 100644
--- a/xmlsecurity/source/helper/documentsignaturehelper.cxx
+++ b/xmlsecurity/source/helper/documentsignaturehelper.cxx
@@ -341,8 +341,8 @@ bool DocumentSignatureHelper::checkIfAllFilesAreSigned(
for ( int i = sigInfo.vSignatureReferenceInfors.size(); i; )
{
const SignatureReferenceInformation& rInf = sigInfo.vSignatureReferenceInfors[--i];
- // There is also an extra entry of type TYPE_SAMEDOCUMENT_REFERENCE because of signature date.
- if ( ( rInf.nType == TYPE_BINARYSTREAM_REFERENCE ) || ( rInf.nType == TYPE_XMLSTREAM_REFERENCE ) )
+ // There is also an extra entry of type SignatureReferenceType::SAMEDOCUMENT because of signature date.
+ if ( ( rInf.nType == SignatureReferenceType::BINARYSTREAM ) || ( rInf.nType == SignatureReferenceType::XMLSTREAM ) )
{
OUString sReferenceURI = rInf.ouURI;
if (alg == OOo2Document)